Rank-Based Evaluation
=====================
.. automodule:: pykeen.evaluation.rank_based_evaluator
.. autoclass:: pykeen.evaluation.RankBasedMetricResults
.. autoclass:: pykeen.evaluation.RankBasedEvaluator
